@@ -35,4 +35,11 @@ class TFilterStopProcessing(pipeline.Filter):
 class TFilterException(pipeline.Filter):
 	def Execute(self, msg):
 		raise IOError
-		
\ No newline at end of file
+		
+class TRouter(pipeline.Router):
+	def Execute(self, msg):
+		if msg.payload == 1:
+			self.Extend(TFilter, 1)
+		else:
+			self.Extend(TFilter, 2)
+		return self.Route(msg)
\ No newline at end of file
